@@ -1,7 +1,7 @@
 package Bencher::Scenario::CmdLineParsingModules;
 
-our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-06-26'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,6 +9,9 @@ use warnings;
 
 our $scenario = {
     summary => 'Benchmark command-line parsing modules',
+    modules => {
+        'Complete::Bash' => {version=>0.27},
+    },
     participants => [
         {
             fcall_template => 'Parse::CommandLine::parse_command_line(<cmdline>)',
@@ -58,11 +61,11 @@ __END__
 
 =head1 NAME
 
-Bencher::Scenario::CmdLineParsingModules
+Bencher::Scenario::CmdLineParsingModules - Benchmark command-line parsing modules
 
 =head1 VERSION
 
-This document describes version 0.03 of Bencher::Scenario::CmdLineParsingModules (from Perl distribution Bencher-Scenario-CmdLineParsingModules), released on 2016-01-05.
+This document describes version 0.04 of Bencher::Scenario::CmdLineParsingModules (from Perl distribution Bencher-Scenario-CmdLineParsingModules), released on 2016-06-26.
 
 =head1 SYNOPSIS
 
@@ -78,9 +81,11 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 =head1 BENCHMARKED MODULES
 
-L<Parse::CommandLine> 0.02
+Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Complete::Bash> 0.24
+L<Complete::Bash> 0.27
+
+L<Parse::CommandLine> 0.02
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -102,37 +107,51 @@ Function call template:
 
 
 
+=back
+
+=head1 BENCHMARK DATASETS
+
+=over
+
+=item * empty
+
+=item * cmd-only
+
+=item * 2args-simple
+
+=item * 4args
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
-Benchmark with default option:
+Benchmark with default options (C<< bencher -m CmdLineParsingModules >>):
 
- +-----+---------------------------------------------------------------------------------+-----------+---------+---------+---------+
- | seq | name                                                                            | rate      | time    | errors  | samples |
- +-----+---------------------------------------------------------------------------------+-----------+---------+---------+---------+
- | 7   | {dataset=>"4args",participant=>"Complete::Bash::parse_cmdline"}                 | 2.41e+04  | 41.6μs  | 1.3e-08 | 20      |
- | 3   | {dataset=>"4args",participant=>"Parse::CommandLine::parse_command_line"}        | 2.66e+04  | 37.6μs  | 5.2e-08 | 21      |
- | 6   | {dataset=>"2args-simple",participant=>"Complete::Bash::parse_cmdline"}          | 5.54e+04  | 18μs    | 2.7e-08 | 20      |
- | 2   | {dataset=>"2args-simple",participant=>"Parse::CommandLine::parse_command_line"} | 1.1e+05   | 9.4μs   | 5.7e-08 | 20      |
- | 5   | {dataset=>"cmd-only",participant=>"Complete::Bash::parse_cmdline"}              | 1.24e+05  | 8.07μs  | 9.8e-09 | 21      |
- | 1   | {dataset=>"cmd-only",participant=>"Parse::CommandLine::parse_command_line"}     | 2.6e+05   | 3.85μs  | 1.6e-09 | 22      |
- | 4   | {dataset=>"empty",participant=>"Complete::Bash::parse_cmdline"}                 | 8.603e+05 | 1.162μs | 4.5e-11 | 20      |
- | 0   | {dataset=>"empty",participant=>"Parse::CommandLine::parse_command_line"}        | 1.76e+06  | 0.569μs | 8.3e-10 | 20      |
- +-----+---------------------------------------------------------------------------------+-----------+---------+---------+---------+
+ +----------------------------------------+--------------+-----------+-----------+------------+---------+---------+
+ | participant                            | dataset      | rate (/s) | time (μs) | vs_slowest |  errors | samples |
+ +----------------------------------------+--------------+-----------+-----------+------------+---------+---------+
+ | Parse::CommandLine::parse_command_line | 4args        |     42900 |  23.3     |    1       | 6.4e-09 |      22 |
+ | Complete::Bash::parse_cmdline          | 4args        |     49000 |  20.4     |    1.14    | 6.5e-09 |      21 |
+ | Complete::Bash::parse_cmdline          | 2args-simple |    117160 |   8.5353  |    2.7292  | 4.7e-11 |      23 |
+ | Parse::CommandLine::parse_command_line | 2args-simple |    168000 |   5.95    |    3.92    | 1.5e-09 |      24 |
+ | Complete::Bash::parse_cmdline          | cmd-only     |    272000 |   3.67    |    6.34    | 1.4e-09 |      27 |
+ | Parse::CommandLine::parse_command_line | cmd-only     |    427079 |   2.34149 |    9.94879 |   0     |      21 |
+ | Complete::Bash::parse_cmdline          | empty        |   1500000 |   0.66    |   36       | 8.1e-10 |      21 |
+ | Parse::CommandLine::parse_command_line | empty        |   2980000 |   0.335   |   69.5     | 1.6e-10 |      32 |
+ +----------------------------------------+--------------+-----------+-----------+------------+---------+---------+
 
 
-Benchmark module startup overhead:
+Benchmark module startup overhead (C<< bencher -m CmdLineParsingModules --module-startup >>):
 
- +-----+---------------------+-------+-------------------+---------+---------+
- | seq | name                | time  | mod_overhead_time | errors  | samples |
- +-----+---------------------+-------+-------------------+---------+---------+
- | 2   | Complete::Bash      | 9.2ms | 4.8ms             | 4.9e-05 | 22      |
- | 1   | Parse::CommandLine  | 8.7ms | 4.3ms             | 4.5e-05 | 20      |
- | 0   | perl -e1 (baseline) | 4.4ms | 0ms               | 3e-05   | 20      |
- +-----+---------------------+-------+-------------------+---------+---------+
+ +---------------------+-----------+------------------------+------------+---------+---------+
+ | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+-----------+------------------------+------------+---------+---------+
+ | Parse::CommandLine  |       5.8 |                    3.2 |        1   | 5.4e-05 |      20 |
+ | Complete::Bash      |       5.4 |                    2.8 |        1.1 | 2.2e-05 |      21 |
+ | perl -e1 (baseline) |       2.6 |                    0   |        2.2 | 1.5e-05 |      20 |
+ +---------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
